@@ -617,6 +617,25 @@ test_that("tidy_plus_plus() works with VGAM::vglm", {
 })
 
 
+test_that("tidy_plus_plus() works with svyVGAM::svy_vglm", {
+  skip_on_cran()
+  skip_if_not_installed("svyVGAM")
+  skip_if_not_installed("parameters")
+  skip_if_not_installed("survey")
+  library(svyVGAM)
+
+  mod <- svy_vglm(
+    stage ~ grade + age,
+    VGAM::multinomial(),
+    design = survey::svydesign(~ 1, data = gtsummary::trial, weights = ~ 1)
+  )
+
+  expect_no_error(
+    res <- mod |> tidy_plus_plus()
+  )
+  expect_true("y.level" %in% colnames(res))
+})
+
 test_that("tidy_plus_plus() works with plm::plm", {
   skip_on_cran()
   skip_if_not_installed("plm")
@@ -634,7 +653,6 @@ test_that("tidy_plus_plus() works with plm::plm", {
   )
 })
 
-
 test_that("tidy_plus_plus() works with biglm::bigglm", {
   skip_on_cran()
   skip_if_not_installed("biglm")
@@ -744,7 +762,7 @@ test_that("tidy_plus_plus() works with multgee models", {
     status ~ factor(time) * sec,
     data = h,
     id = id,
-    repeated = time,
+    repeated = time
   )
   expect_no_error(
     res <- mod |> tidy_plus_plus()
